@@ -16,10 +16,12 @@ from identitylib.card_client.model.card_identifier import CardIdentifier
 from identitylib.card_client.model.card_logo import CardLogo
 from identitylib.card_client.model.card_note import CardNote
 from identitylib.card_client.model.card_request import CardRequest
+from identitylib.card_client.model.card_request_distinct_values import CardRequestDistinctValues
 from identitylib.card_client.model.card_request_summary import CardRequestSummary
 from identitylib.card_client.model.card_summary import CardSummary
 from identitylib.card_client.model.inline_object import InlineObject
 from identitylib.card_client.model.inline_object1 import InlineObject1
+from identitylib.card_client.model.inline_object2 import InlineObject2
 from identitylib.card_client.model.inline_response200 import InlineResponse200
 from identitylib.card_client.model.inline_response2001 import InlineResponse2001
 from identitylib.card_client.model.inline_response2002 import InlineResponse2002
@@ -27,7 +29,10 @@ from identitylib.card_client.model.inline_response2003 import InlineResponse2003
 from identitylib.card_client.model.inline_response2004 import InlineResponse2004
 from identitylib.card_client.model.inline_response2005 import InlineResponse2005
 from identitylib.card_client.model.inline_response2006 import InlineResponse2006
+from identitylib.card_client.model.inline_response2006_details import InlineResponse2006Details
 from identitylib.card_client.model.inline_response2007 import InlineResponse2007
-from identitylib.card_client.model.inline_response2007_results import InlineResponse2007Results
-from identitylib.card_client.model.v1beta1_card_requests_id_identifiers import V1beta1CardRequestsIdIdentifiers
+from identitylib.card_client.model.inline_response2008 import InlineResponse2008
+from identitylib.card_client.model.inline_response2008_results import InlineResponse2008Results
+from identitylib.card_client.model.v1beta1_card_requests_update_identifiers import V1beta1CardRequestsUpdateIdentifiers
+from identitylib.card_client.model.v1beta1_card_requests_update_updates import V1beta1CardRequestsUpdateUpdates
 from identitylib.card_client.model.validation_error import ValidationError
